;; Generated package description from setup.el  -*- no-byte-compile: t -*-
(define-package "setup" "1.5.0.0.20250829.105526" "Helpful Configuration Macro" '((emacs "26.1")) :commit "0cf74c50d90c00450f8a3425c1b84b3bccd99f84" :authors '(("Philip Kaludercic" . "philipk@posteo.net")) :maintainer '("Philip Kaludercic" . "philipk@posteo.net") :keywords '("lisp" "local") :url "https://codeberg.org/pkal/setup.el")
